/****************************************************************************
* Title                 :   Force click
* Filename              :   Force.c
* Author                :   Aleksandar Mitrovic
* Origin Date           :   18/07/2016
* Notes                 :   Force Example
*****************************************************************************/
/**************************CHANGE LIST **************************************
*
*    Date    Software Version    Initials       Description
*  27/06/16       1.2.1            LA        This is a demonstration of using Force click.
                                             Analog 10-bit value on AN pin increases when stretching
*
*****************************************************************************/
/**
 * @file Force.c
 * @brief <h2> Force Example </h2>
 *
 * @par
 * Example for <a href="http://www.mikroe.com">MikroElektronika's</a>
 * Force click board.
 */

#include "resources.h"
#include "built_in.h"

static unsigned int adc_rd;
static char txt[6];
int adc_res,adc_res_old;

const double Vadc_5  = 4.8828125;         // ADC step 5V/1024 4,88mV (10bit ADC)
const double Vadc_33 = 3.2226562;         // ADC step 3,3V/1024 3,22mV (10bit ADC)

// TFT module connections
char TFT_DataPort at GPIO_PORT_32_39;
sbit TFT_RST at GPIO_PIN42_bit;
sbit TFT_RS at GPIO_PIN40_bit;
sbit TFT_CS at GPIO_PIN41_bit;
sbit TFT_RD at GPIO_PIN46_bit;
sbit TFT_WR at GPIO_PIN47_bit;
sbit TFT_BLED at GPIO_PIN58_bit;
// End TFT module connections

//Definitions
void Auxiliary_Code() {
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}
void Set_Index(unsigned short index) {
  TFT_RS = 0;
  asm nop;
  TFT_DataPort = index;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Command(unsigned short cmd) {
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = cmd;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Data(unsigned int _data) {
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = Hi(_data);
  asm nop; asm nop;
  Auxiliary_Code();
  asm nop;
  TFT_DataPort = Lo(_data);
  asm nop; asm nop;
  Auxiliary_Code();
}

void Display_Init()
{
    TFT_Set_Active(Set_Index, Write_Command, Write_Data);
    TFT_Init_ILI9341_8bit(320, 240);
    TFT_BLED = 1;
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
    TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
    TFT_Fill_Screen(CL_WHITE);
    TFT_Set_Pen(CL_Black, 1);
    TFT_Line(20, 220, 300, 220);
    TFT_LIne(20,  46, 300,  46);
    TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
    TFT_Write_Text("Force Click", 100, 14);
    TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
    TFT_Write_Text("EasyFT90x v7", 19, 223);
    TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
    TFT_Write_Text("www.mikroe.com", 200, 223);
    TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_BLACK, FO_HORIZONTAL);
    TFT_Write_Text("Force ADC [V] :", 40, 110);
}

/*
 * Read data from sensor
 * reads ADC value from AN pin
 */
static void readSensor()
{
    adc_rd = ADC_Get_Sample(4);               // Get ADC value from corresponding channel
    delay_ms(10);                             // Pause 10ms
}


/*
 * Initialize ADC
 */
static void set_adc()
{
    ADC_Init();
    ADC_Set_Input_Channel(_ADC_CHANNEL_4);
}
void main()
{
    set_adc();                                                         // Initialize ADC
    Display_Init();                                                    // Initialize TFT
    TFT_Set_Pen(CL_WHITE, 1);
    TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
    while(1)
    {
        readSensor(); 
        adc_res = ((double)adc_rd * Vadc_33); // volatage input and resolution
                                                 // 3.226 = 3300/1023                                                 // Read sensor
        TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_WHITE, FO_HORIZONTAL);
        TFT_Write_Text(txt, 190, 110);
        WordToStr(adc_res,txt);                                                 // Conversion integer adc_rd to string txt
        TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_BLACK, FO_HORIZONTAL);   // Display string on TFT
        TFT_Write_Text(txt, 190, 110);                                           // Print txt value on TFT
        delay_ms(100);
        adc_res = adc_res_old;
    }

}